@@ -1,12 +1,14 @@
 import json
 import datetime
-import time
-from functools import wraps
+import random
+import string
+import hashlib
+from copy import deepcopy
+from functools import reduce
 
 
 def md5(_str):
     """ md5 string """
-    import hashlib
     if isinstance(_str, bytes):
         return hashlib.md5(_str).hexdigest()
     elif isinstance(_str, str):
@@ -15,7 +17,6 @@ def md5(_str):
 
 def rstr(n: int = 32) -> str:  # noqa
     """ random string """
-    import random, string
     return ''.join(random.choices(
         string.digits + string.ascii_lowercase + string.ascii_uppercase,
         k=n
@@ -24,10 +25,9 @@ def rstr(n: int = 32) -> str:  # noqa
 
 def ip_to_int(ip: str):
     """ IP convert to int """
-    import functools
     # 192.168.1.13
     # (((((192 * 256) + 168) * 256) + 1) * 256) + 13
-    return functools.reduce(lambda x, y: (x << 8) + y, map(int, ip.split('.')))
+    return reduce(lambda x, y: (x << 8) + y, map(int, ip.split('.')))
 
 
 def int_to_ip(ip: int) -> str:
@@ -97,8 +97,6 @@ class JSONEncoder(json.JSONEncoder):
 
 
 def obj_hook(obj, fmt=None):
-    from copy import deepcopy
-
     time_fmt = [
         '%d/%m/%Y %H:%M%S',
         '%d/%m/%YT%H:%M%S',
@@ -145,7 +143,7 @@ def json_load(data: str):
 
 
 class SortedObj(object):
-    """可排序对象"""
+    """可比较对象"""
 
     def __init__(self):
         import time
@@ -199,50 +197,3 @@ def run(f, *args, onerror=None, onsuccess=None, **kwargs):
         if callable(onerror):
             return onsuccess(e)
         raise e
-
-
-def run_decorator(onerror=None, onsuccess=None):
-    def inner(f):
-        @wraps(f)
-        def _inner(*args, **kwargs):
-            try:
-                ret = f(*args, **kwargs)
-                if callable(onsuccess):
-                    return onsuccess(ret)
-                return ret
-            except Exception as e:
-                if callable(onerror):
-                    return onerror(e)
-                raise e
-
-        return _inner
-
-    return inner
-
-
-def retry_decorator(times=0, interval=0, onerror=None, onretry=None, onsuccess=None):
-    def _retry(f, _times, *args, **kwargs):
-        try:
-            ret = f(*args, **kwargs)
-            if callable(onsuccess):
-                return run(onsuccess, ret, onerror=lambda e: None)
-            return ret
-        except Exception as exc:
-            if _times > 0:
-                if callable(onretry):
-                    return run(onretry, exc=exc, onerror=lambda e: None)
-                if interval > 0:
-                    time.sleep(interval)
-                return _retry(f, _times - 1, *args, **kwargs)
-            if callable(onerror):
-                return run(onerror, exc=exc, onerror=lambda e: None)
-            raise exc
-
-    def inner(f):
-        @wraps(f)
-        def _inner(*args, **kwargs):
-            return _retry(f, times, *args, **kwargs)
-
-        return _inner
-
-    return inner
